## cdist-type__ssh_dot_ssh(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__ssh_dot_ssh - Manage .ssh directory

## 2. DESCRIPTION

Adds or removes .ssh directory to a user home.

This type is being used by __ssh_authorized_keys.

## 3. OPTIONAL PARAMETERS

state
  if the directory should be present or absent, defaults to present.

## 4. EXAMPLES

    # Ensure root has ~/.ssh with the right permissions
    __ssh_dot_ssh root

    # Nico does not need ~/.ssh anymore
    __ssh_dot_ssh nico --state absent

## 5. SEE ALSO

- cdist-type(7)
- cdist-type__ssh_authorized_keys(7)

## 6. COPYING

Copyright (C) 2014 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).